/*
 * ﻿Copyright (C) 2011-2013 NewMain Softech
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package com.newmainsoftech.aspectjutil.eventmanager.label;

import java.lang.annotation.ElementType;
import java.lang.annotation.Inherited;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

import com.newmainsoftech.aspectjutil.eventmanager.EventHandler;

/**
 * Just marker annotation on class (not interface) going to listen some event(s). <br /> 
 * Additionally, event listener method (what will be executed by listening event) needs to 
 * have either {@link PreEvent} or {@link OnEvent} annotation, or both. <br />
 * CUATION: this will be treated as being INHERITED.<br />
 * <br />
 * For usage example, see {@link EventHandler} JavaDoc.
 * 
 * @author <a href="mailto:artymt@gmail.com">Arata Y.</a>
 */
@Retention(RetentionPolicy.RUNTIME)
@Target( {ElementType.TYPE})
@Inherited
public @interface EventListener { // This type is just maker
	/*
	 * Order among listeners. Lower the value higher the precedence.
	 */
//	public int value() default 0;	
	
	/**
	 * Specify whether keep listener instance or make it subject of garbage collection. <br />
	 * If the life span of the listener instance is known in advance, then you may set this true.<br />
	 * Default is false.
	 * 
	 * @return true when listener instance is subject of garbage collection.
	 */
	public boolean gcSubject() default false;
}
