/*
 * ﻿Copyright (C) 2011-2013 NewMain Softech
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package com.newmainsoftech.aspectjutil.eventmanager.label;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

import com.newmainsoftech.aspectjutil.eventmanager.EventHandler;

/**
 * Method with this annotation trigger the specified event type(s). <br />
 * CUATION: 
 * <ul>
 * <li>This annotation will be be treated as being INHERITED.</li>
 * <li>Though it is stated so about inheritance, there is not difference with regular annotation about 
 * not using on method in interface definition; rather should be used on method or field in concrete class 
 * definition.</li>
 * </ul> 
 * <br />
 * For usage example, see {@link EventHandler} JavaDoc.
 * 
 * @author <a href="mailto:artymt@gmail.com">Arata Y.</a>
 */
@Retention(RetentionPolicy.RUNTIME)
@Target( {ElementType.METHOD, ElementType.FIELD})
public @interface EventTrigger {
	/**
	 * @return Types of events being triggered
	 */
	public Class<?> value();
}
